@@ -5,6 +5,8 @@
 # your platform
 #
 PATH_TO_SIKULI_JAR=/Applications/Sikuli-IDE.app/Contents/Resources/Java/
-cd src
+PACKAGE_PATH=`python -c "import jython_sikuli_server; import os; print os.path.dirname(os.path.dirname(jython_sikuli_server.__file__))"`
+CURRENT_DIR=`pwd`
+cd $PACKAGE_PATH
 java -cp "$PATH_TO_SIKULI_JAR/sikuli-script.jar" org.python.util.jython -m jython_sikuli_server
-cd ..
+cd $CURRENT_DIR
